summaryrefslogtreecommitdiffstats
path: root/src/com/vaadin/terminal/PaintTarget.java
diff options
context:
space:
mode:
authorMatti Tahvonen <matti.tahvonen@itmill.com>2010-11-03 21:53:53 +0000
committerMatti Tahvonen <matti.tahvonen@itmill.com>2010-11-03 21:53:53 +0000
commit83c63a773c12541718895329775594e283c3ccb9 (patch)
tree60aeb89183b0fce973cafc758eb2070b4ecda9d7 /src/com/vaadin/terminal/PaintTarget.java
parentf30ee0dc5252ac742c000fd6cfd50eb8899479aa (diff)
downloadvaadin-framework-83c63a773c12541718895329775594e283c3ccb9.tar.gz
vaadin-framework-83c63a773c12541718895329775594e283c3ccb9.zip
#5743, #5742, #5741, #4275 related refactoring. Renamed com.vaadin.terminal.Receiver (introduced earlier in this dev branch) to StreamVariable and combined ReceiverOwner methods to it. Resetted Upload.Receiver to 6.4 state, DD wrapper uses StreamVariable based API (breaking change, but very rare code atm)
svn changeset:15849/svn branch:6.5
Diffstat (limited to 'src/com/vaadin/terminal/PaintTarget.java')
-rw-r--r--src/com/vaadin/terminal/PaintTarget.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/com/vaadin/terminal/PaintTarget.java b/src/com/vaadin/terminal/PaintTarget.java
index 2ee69247e7..76ebd19a7d 100644
--- a/src/com/vaadin/terminal/PaintTarget.java
+++ b/src/com/vaadin/terminal/PaintTarget.java
@@ -152,26 +152,26 @@ public interface PaintTarget extends Serializable {
public void addAttribute(String name, Resource value) throws PaintException;
/**
* Adds details about {@link Receiver} to the UIDL stream. Eg. in web
* terminals Receivers are typically rendered for the client side as URLs,
* where the client side implementation can do an http post request.
* <p>
* Note that a Receiver can only be used once per "paint". The same Receiver
* can be used several times, but it must be repainted before the next
* stream can be received.
*
* @param owner
* the ReceiverOwner that can track the progress of streaming to
- * the given Receiver
+ * the given StreamVariable
* @param name
- * an identifying name for the Receiver
+ * an identifying name for the StreamVariable
* @param value
- * the Receiver to paint
+ * the StreamVariable to paint
*
* @throws PaintException
* if the paint operation failed.
*/
- public void addVariable(ReceiverOwner owner, String name, Receiver value)
+ public void addVariable(VariableOwner owner, String name, StreamVariable value)
throws PaintException;
/**
@@ -152,26 +152,26 @@ public interface PaintTarget extends Serializable {
public void addAttribute(String name, Resource value) throws PaintException;
/**
- * Adds details about {@link Receiver} to the UIDL stream. Eg. in web
+ * Adds details about {@link StreamVariable} to the UIDL stream. Eg. in web
* terminals Receivers are typically rendered for the client side as URLs,
* where the client side implementation can do an http post request.
@@ -152,26 +152,26 @@ public interface PaintTarget extends Serializable {
* where the client side implementation can do an http post request.
* <p>
- * Note that a Receiver can only be used once per "paint". The same Receiver
+ * Note that a StreamVariable can only be used once per "paint". The same StreamVariable
* can be used several times, but it must be repainted before the next
* stream can be received.